# gengive

[![license](https://img.shields.io/github/license/sthagen/gengive.svg?style=flat)](https://github.com/sthagen/gengive/blob/default/LICENSE)
[![version](https://img.shields.io/pypi/v/gengive.svg?style=flat)](https://pypi.python.org/pypi/gengive/)
[![downloads](https://pepy.tech/badge/gengive/month)](https://pepy.tech/project/gengive)
[![wheel](https://img.shields.io/pypi/wheel/gengive.svg?style=flat)](https://pypi.python.org/pypi/gengive/)
[![supported-versions](https://img.shields.io/pypi/pyversions/gengive.svg?style=flat)](https://pypi.python.org/pypi/gengive/)
[![supported-implementations](https://img.shields.io/pypi/implementation/gengive.svg?style=flat)](https://pypi.python.org/pypi/gengive/)

Render text (Danish: gengive tekst).

## Status

Experimental.

**Note**: The default branch is `default`.
